@@ -340,13 +340,14 @@ static void init(int argc, char** argv)
 
   getopt_merge(long_options, webbase_options(long_options));
 
+  opterr = 0;
   optind = 0;
   while(1) {
     /* `getopt_long' stores the option index here. */
     int option_index = 0;
     int c;
 
-    c = getopt_long_only(argc, argv, "", long_options, &option_index);
+    c = getopt_long_only(argc, argv, "-", long_options, &option_index);
 
     /* Detect the end of the options. */
     if (c == -1)
@@ -365,9 +366,6 @@ static void init(int argc, char** argv)
 	} else if(!strcmp(long_options[option_index].name, "")) {
 	}
 	break;
-      default:
-	fprintf(stderr, "option parse error %c, 0x%x\n", c & 0xff, c);
-	exit(1);
       }
   }
 
