@@ -24,10 +24,6 @@
 #include <mysql.h>
 #include <uri.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 #define WEBBASE_NAME_LENGTH 		128
 #define WEBBASE_PATH_LENGTH 		1024
 #define WEBBASE_HOST_LENGTH 		256
@@ -112,8 +108,4 @@ int webbase_insert_start2url(webbase_t* base, int start_rowid, int url_rowid, in
 int webbase_get_start2url(webbase_t* base, int* start_rowid, int* url_rowid, int* level);
 int webbase_counted(webbase_t* base, webbase_url_start_t* start, int rowid);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif /* _webbase_h */
