@@ -56,7 +56,7 @@ class WebbaseHookMifluz : public WebbaseHook {
   //
   // Mifluz implementation
   //
-  int Open();
+  int Open(int flags);
   int Close();
   char* Database() const;
   int  InsertChunk(int info, html_content_parsed_t* parsed);
