@@ -26,7 +26,7 @@ unsigned char iso2letter_unaccent[256];
 unsigned char iso2letter_transparent[256];
 static int iso_done = 0;
 
-unsigned char* unaccent(unsigned char* string)
+unsigned char* unaccent(unsigned char* string, int string_length)
 {
   if(!iso_done) {
     char* tmp = "AAAAAAACEEEEIIIIDNOOOOOxOUUUUYdBaaaaaaaceeeeiiiionooooo/ouuuuydy";
@@ -42,10 +42,9 @@ unsigned char* unaccent(unsigned char* string)
 
   {
     unsigned char* tmp = string;
-    while(*tmp) {
-      *tmp = iso2letter_unaccent[(unsigned char)*tmp];
-      tmp++;
-    }
+    int i;
+    for(i = 0; i < string_length; i++)
+      tmp[i] = iso2letter_unaccent[(unsigned char)tmp[i]];
   }
   return string;
 }
