@@ -30,7 +30,15 @@
 # endif
 #endif
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 void time_register(time_t* timevar);
 time_t time_show(char* message, time_t timevar);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* _timer_h */
